@@ -19,16 +19,22 @@
 
 #include <unistd.h>
 #include <sys/types.h>
-#include <sys/socket.h>
+#include <ncp/ext/socket.h>
+/* TBD */
 #include <netinet/in.h>
+#ifdef HAVE_NETINET_IF_ETHER_H
+#include <netinet/if_ether.h>
+#else
 #include <linux/if_ether.h>
-#include <strings.h>
+#endif
+#include <string.h>
 #include <sys/ioctl.h>
-#include <linux/if.h>
+#include <ncp/kernel/if.h>
 #include <signal.h>
-#include <linux/ip.h>
-#include <linux/tcp.h>
-#include <netinet/protocols.h>
+/* TBD */
+#include <netinet/ip.h>
+/* TBD */
+#include <netinet/tcp.h>
 #include <stdio.h>
 #include <time.h>
 #include <signal.h>
@@ -37,18 +43,20 @@
 
 #define DUMPALLSAPS		/* #define if you want to dump all SAP's */
 
-struct ipx_address {
-	unsigned long net;
-	unsigned char node[IPX_NODE_LEN];
-	unsigned short sock;
+struct ipx_address
+{
+	IPXNet	net	__attribute__((packed));
+	IPXNode	node	__attribute__((packed));
+	IPXPort	sock	__attribute__((packed));
 };
 
-struct ipx_packet {
-	unsigned short ipx_checksum;
+struct ipx_packet
+{
+	unsigned short ipx_checksum	__attribute__((packed));
 #define IPX_NO_CHECKSUM	0xFFFF
-	unsigned short ipx_pktsize;
-	unsigned char ipx_tctrl;
-	unsigned char ipx_type;
+	unsigned short ipx_pktsize	__attribute__((packed));
+	unsigned char ipx_tctrl		__attribute__((packed));
+	unsigned char ipx_type		__attribute__((packed));
 #define IPX_TYPE_UNKNOWN	0x00
 #define IPX_TYPE_RIP		0x01	/* may also be 0 */
 #define IPX_TYPE_SAP		0x04	/* may also be 0 */
@@ -63,46 +71,49 @@ struct ipx_packet {
 #define NCP_REQUEST              (0x2222)
 #define NCP_DEALLOC_SLOT_REQUEST (0x5555)
 
-struct ncp_request_header {
-	__u16 type __attribute__((packed));
-	__u8 sequence __attribute__((packed));
-	__u8 conn_low __attribute__((packed));
-	__u8 task __attribute__((packed));
-	__u8 conn_high __attribute__((packed));
-	__u8 function __attribute__((packed));
-	__u8 data[0] __attribute__((packed));
+struct ncp_request_header
+{
+	u_int16_t type __attribute__((packed));
+	u_int8_t sequence __attribute__((packed));
+	u_int8_t conn_low __attribute__((packed));
+	u_int8_t task __attribute__((packed));
+	u_int8_t conn_high __attribute__((packed));
+	u_int8_t function __attribute__((packed));
+	u_int8_t data[0] __attribute__((packed));
 };
 
 #define NCP_REPLY                (0x3333)
 #define NCP_POSITIVE_ACK         (0x9999)
 
-struct ncp_reply_header {
-	__u16 type __attribute__((packed));
-	__u8 sequence __attribute__((packed));
-	__u8 conn_low __attribute__((packed));
-	__u8 task __attribute__((packed));
-	__u8 conn_high __attribute__((packed));
-	__u8 completion_code __attribute__((packed));
-	__u8 connection_state __attribute__((packed));
-	__u8 data[0] __attribute__((packed));
+struct ncp_reply_header
+{
+	u_int16_t type __attribute__((packed));
+	u_int8_t sequence __attribute__((packed));
+	u_int8_t conn_low __attribute__((packed));
+	u_int8_t task __attribute__((packed));
+	u_int8_t conn_high __attribute__((packed));
+	u_int8_t completion_code __attribute__((packed));
+	u_int8_t connection_state __attribute__((packed));
+	u_int8_t data[0] __attribute__((packed));
 };
 
 #define NCP_BURST_PACKET         (0x7777)
 
-struct ncp_burst_header {
-	__u16 type __attribute__((packed));
-	__u8 system_flags __attribute__((packed));
-	__u8 stream_type __attribute__((packed));
-	__u32 source_conn __attribute__((packed));
-	__u32 dest_conn __attribute__((packed));
-	__u32 packet_sequence __attribute__((packed));
-	__u32 send_delay __attribute__((packed));
-	__u16 burst_sequence __attribute__((packed));
-	__u16 ack_sequence __attribute__((packed));
-	__u32 burst_length __attribute__((packed));
-	__u32 data_offset __attribute__((packed));
-	__u16 data_bytes __attribute__((packed));
-	__u16 missing_frags __attribute__((packed));
+struct ncp_burst_header
+{
+	u_int16_t type __attribute__((packed));
+	u_int8_t system_flags __attribute__((packed));
+	u_int8_t stream_type __attribute__((packed));
+	u_int32_t source_conn __attribute__((packed));
+	u_int32_t dest_conn __attribute__((packed));
+	u_int32_t packet_sequence __attribute__((packed));
+	u_int32_t send_delay __attribute__((packed));
+	u_int16_t burst_sequence __attribute__((packed));
+	u_int16_t ack_sequence __attribute__((packed));
+	u_int32_t burst_length __attribute__((packed));
+	u_int32_t data_offset __attribute__((packed));
+	u_int16_t data_bytes __attribute__((packed));
+	u_int16_t missing_frags __attribute__((packed));
 };
 
 void handle_ipx(unsigned char *buf, int length, char *frame, int no);
@@ -120,29 +131,37 @@ int handle_burst(struct sockaddr_ipx *source,
 /* SAP Query structure (returned in sap_packet as an array)
  * NBO == Network Byte Order)
  */
-typedef struct saps {
-	__u16 serverType __attribute__((packed));	/* NBO */
-	__u8 serverName[SAP_MAX_SERVER_NAME_LENGTH] __attribute__((packed));
+typedef struct saps
+{
+	u_int16_t serverType __attribute__((packed));	/* NBO */
+	u_int8_t serverName[SAP_MAX_SERVER_NAME_LENGTH] __attribute__((packed));
 	struct ipx_address serverAddress __attribute__((packed));
-	__u16 serverHops __attribute__((packed));	/* NBO */
-} SAPS;
+	u_int16_t serverHops __attribute__((packed));	/* NBO */
+}
+SAPS;
 
 /* General Service/Nearest Server Response SAP packet */
-union sap_packet {
+union sap_packet
+{
 	unsigned short sapOperation;
-	struct sap_query {
-		__u16 sapOperation __attribute__((packed));
-		__u16 serverType __attribute__((packed));
-	} query;
-	struct sap_response {
-		__u16 sapOperation __attribute__((packed));
+	struct sap_query
+	{
+		u_int16_t sapOperation __attribute__((packed));
+		u_int16_t serverType __attribute__((packed));
+	}
+	query;
+	struct sap_response
+	{
+		u_int16_t sapOperation __attribute__((packed));
 		/* each SAP can has a max of SAP_MAX_SAPS_PER_PACKET packets */
 		SAPS sap[SAP_MAX_SAPS_PER_PACKET] __attribute__((packed));
-	} response;
+	}
+	response;
 };
 
 /* print out one SAP record */
-static void print_sap(FILE * file, SAPS * sapp)
+static void
+print_sap(FILE * file, SAPS * sapp)
 {
 	fprintf(file, "  Name:%s, serverType 0x%x, ",
 		sapp->serverName,
@@ -155,7 +174,8 @@ static void print_sap(FILE * file, SAPS * sapp)
 	fprintf(file, " (Hops %d)\n", ntohs(sapp->serverHops));
 }
 
-void handle_ipx(unsigned char *buf, int length, char *frame, int no)
+void
+handle_ipx(unsigned char *buf, int length, char *frame, int no)
 {
 	struct ipx_packet *h = (struct ipx_packet *) buf;
 	struct sockaddr_ipx s_addr;
@@ -183,11 +203,13 @@ void handle_ipx(unsigned char *buf, int length, char *frame, int no)
 	printf("\n");
 
 	if (handle_burst(&s_addr, &d_addr, buf + sizeof(struct ipx_packet),
-			 length - sizeof(struct ipx_packet), no) != 0) {
+			 length - sizeof(struct ipx_packet), no) != 0)
+	{
 		return;
 	}
 	if ((ntohs(s_addr.sipx_port) == 0x451)
-	    || (ntohs(d_addr.sipx_port) == 0x451)) {
+	    || (ntohs(d_addr.sipx_port) == 0x451))
+	{
 		handle_ncp(&s_addr, &d_addr, buf + sizeof(struct ipx_packet),
 			   length - sizeof(struct ipx_packet), no);
 	} else
@@ -198,21 +220,25 @@ void handle_ipx(unsigned char *buf, int length, char *frame, int no)
 		printf(" type 0x05 (SPX sequenced packet)\n");
 	else if (h->ipx_type == 0x14)
 		printf(" type 0x14 (propogated Client-NetBios)\n");
-	else {
+	else
+	{
 		hbo_dsock = ntohs(d_addr.sipx_port);
-		if (hbo_dsock == 0x452) {	/* SAP */
+		if (hbo_dsock == 0x452)		/* SAP */
+		{
 			sappacket = (union sap_packet *)
 			    (buf + sizeof(struct ipx_packet));
 			hbo_sapop = ntohs(sappacket->sapOperation);
-			if ((hbo_sapop == 0x01) || (hbo_sapop == 0x03)) {
+			if ((hbo_sapop == 0x01) || (hbo_sapop == 0x03))
+			{
 				printf(" type 0x%x, SAP op:0x%x %s Query, "
 				       "serverType 0x%x wanted\n",
 				       h->ipx_type, hbo_sapop,
-				(hbo_sapop == 0x01) ? "General Service" :
-				 (hbo_sapop == 0x03) ? "Nearest Server" :
+				     (hbo_sapop == 0x01) ? "General Service" :
+				       (hbo_sapop == 0x03) ? "Nearest Server" :
 				       "Error",
-				     ntohs(sappacket->query.serverType));
-			} else {
+				       ntohs(sappacket->query.serverType));
+			} else
+			{
 				int hops;
 
 				hops = ntohs(sappacket->
@@ -228,18 +254,20 @@ void handle_ipx(unsigned char *buf, int length, char *frame, int no)
 				       ? "[Shutdown]" : "");
 
 				/* Service ending */
-				if (hops >= SAP_SHUTDOWN) {
+				if (hops >= SAP_SHUTDOWN)
+				{
 					print_sap(stdout,
-						sappacket->response.sap);
+						  sappacket->response.sap);
 				}
 #ifdef DUMPALLSAPS
 				/* If you want to dump all SAP's */
-				else {
+				else
+				{
 					int num_saps;
 					SAPS *sapp;
 
 					num_saps = (length
-					      - sizeof(struct ipx_packet)
+						    - sizeof(struct ipx_packet)
 						    - 2) / sizeof(SAPS);
 
 					sapp = sappacket->response.sap;
@@ -263,13 +291,15 @@ void handle_ipx(unsigned char *buf, int length, char *frame, int no)
 
 }
 
-int handle_burst(struct sockaddr_ipx *source,
-		 struct sockaddr_ipx *target,
-		 unsigned char *buf, int length, int no)
+int
+handle_burst(struct sockaddr_ipx *source,
+	     struct sockaddr_ipx *target,
+	     unsigned char *buf, int length, int no)
 {
 	struct ncp_burst_header *rq = (struct ncp_burst_header *) buf;
 
-	if (rq->type != NCP_BURST_PACKET) {
+	if (rq->type != NCP_BURST_PACKET)
+	{
 		return 0;
 	}
 	printf("Burst Packet\n");
@@ -279,22 +309,25 @@ int handle_burst(struct sockaddr_ipx *source,
 	       rq->source_conn, rq->dest_conn,
 	       (unsigned int) ntohl(rq->packet_sequence));
 	printf("Send Delay:  %08X, Burst Seq: %04X, Ack Seq: %04X\n",
-	 (unsigned int) ntohl(rq->send_delay), ntohs(rq->burst_sequence),
+	       (unsigned int) ntohl(rq->send_delay), ntohs(rq->burst_sequence),
 	       ntohs(rq->ack_sequence));
 	printf("Burst Length: %08X\n", (unsigned int) ntohl(rq->burst_length));
 	printf("Data Offset: %08X, Data Bytes: %04X, Missing Frags: %04X\n",
-	    (unsigned int) ntohl(rq->data_offset), ntohs(rq->data_bytes),
+	       (unsigned int) ntohl(rq->data_offset), ntohs(rq->data_bytes),
 	       ntohs(rq->missing_frags));
 
-	if (ntohs(rq->data_bytes) == 24) {
-		struct ncp_burst_request {
+	if (ntohs(rq->data_bytes) == 24)
+	{
+		struct ncp_burst_request
+		{
 			struct ncp_burst_header h __attribute__((packed));
-			__u32 function __attribute__((packed));
-			__u32 file_handle __attribute__((packed));
-			__u8 reserved[8] __attribute__((packed));
-			__u32 file_offset __attribute__((packed));
-			__u32 number_of_bytes __attribute__((packed));
-		} *brq = (struct ncp_burst_request *) rq;
+			u_int32_t function __attribute__((packed));
+			u_int32_t file_handle __attribute__((packed));
+			u_int8_t reserved[8] __attribute__((packed));
+			u_int32_t file_offset __attribute__((packed));
+			u_int32_t number_of_bytes __attribute__((packed));
+		}
+		*brq = (struct ncp_burst_request *) rq;
 
 		printf("Assuming Burst Request:\n");
 		printf("%s: Handle %08X, Offset %08X, Bytes %08X\n",
@@ -307,9 +340,10 @@ int handle_burst(struct sockaddr_ipx *source,
 	return 1;
 }
 
-void handle_ncp(struct sockaddr_ipx *source,
-		struct sockaddr_ipx *target,
-		unsigned char *buf, int length, int no)
+void
+handle_ncp(struct sockaddr_ipx *source,
+	   struct sockaddr_ipx *target,
+	   unsigned char *buf, int length, int no)
 {
 	struct ncp_request_header *rq = (struct ncp_request_header *) buf;
 	struct ncp_reply_header *rs = (struct ncp_reply_header *) buf;
@@ -321,7 +355,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 	static struct ncp_request_header request_header;
 	static char request_data[5];
 
-	if (ntohs(rq->type) == NCP_REQUEST) {
+	if (ntohs(rq->type) == NCP_REQUEST)
+	{
 		/* Request */
 		printf("NCP request: conn: %-5d, seq: %-3d, task: %-3d, ",
 		       rq->conn_low + 256 * rq->conn_high,
@@ -334,7 +369,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 		data = buf + sizeof(struct ncp_request_header);
 		data_length = length - sizeof(struct ncp_request_header);
 
-		switch (rq->function) {
+		switch (rq->function)
+		{
 		case 18:
 			printf("fn: %-3d\n", rq->function);
 			printf("Get Volume Info with Number\n");
@@ -346,7 +382,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 		case 21:
 			printf("fn: %-3d, subfn: %-3d\n",
 			       rq->function, data[2]);
-			switch (data[2]) {
+			switch (data[2])
+			{
 			case 0:
 				printf("Send Broadcast Message\n");
 				break;
@@ -360,7 +397,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 		case 22:
 			printf("fn: %-3d, subfn: %-3d\n",
 			       rq->function, data[2]);
-			switch (data[2]) {
+			switch (data[2])
+			{
 			case 00:
 				printf("Set Directory Handle\n");
 				break;
@@ -404,7 +442,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 		case 23:
 			printf("fn: %-3d, subfn: %-3d\n", rq->function,
 			       data[2]);
-			switch (data[2]) {
+			switch (data[2])
+			{
 			case 17:
 				printf("Get Fileserver Information\n");
 				break;
@@ -527,7 +566,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 		case 87:
 			printf("fn: %-3d, subfn: %-3d\n",
 			       rq->function, data[0]);
-			switch (data[0]) {
+			switch (data[0])
+			{
 			case 1:
 				{
 					unsigned char *p = &(data[0]);
@@ -535,11 +575,11 @@ void handle_ncp(struct sockaddr_ipx *source,
 					printf("Name Space: %d\n", p[1]);
 					printf("Open Create Mode: %x\n", p[2]);
 					printf("Search Attributes: %x\n",
-					       *(__u16 *) & (p[3]));
+					       *(u_int16_t *) & (p[3]));
 					printf("Return Information Mask: %x\n",
-					       (unsigned int) (*(__u32 *) & (p[5])));
+					(unsigned int) (*(u_int32_t *) & (p[5])));
 					printf("Desired Access Rights: %x\n",
-					       *(__u16 *) & (p[9]));
+					       *(u_int16_t *) & (p[9]));
 					break;
 				}
 			case 2:
@@ -564,10 +604,12 @@ void handle_ncp(struct sockaddr_ipx *source,
 			break;
 		case 97:
 			{
-				struct INPUT {
-					__u16 proposed_max_size;
-					__u8 security_flag;
-				} *i = (struct INPUT *) data;
+				struct INPUT
+				{
+					u_int16_t proposed_max_size;
+					u_int8_t security_flag;
+				}
+				*i = (struct INPUT *) data;
 
 				printf("fn: %-3d\n", rq->function);
 				printf("Get Big Packet NCP Max Packet Size\n");
@@ -579,26 +621,28 @@ void handle_ncp(struct sockaddr_ipx *source,
 			}
 		case 101:
 			{
-				struct INPUT {
-					__u32 local_conn_id;
-					__u32 local_max_packet_size;
-					__u16 local_target_socket;
-					__u32 local_max_send_size;
-					__u32 local_max_recv_size;
-				} *i = (struct INPUT *) data;
+				struct INPUT
+				{
+					u_int32_t local_conn_id;
+					u_int32_t local_max_packet_size;
+					u_int16_t local_target_socket;
+					u_int32_t local_max_send_size;
+					u_int32_t local_max_recv_size;
+				}
+				*i = (struct INPUT *) data;
 
 				printf("fn: %-3d\n", rq->function);
 				printf("Packet Burst Connection Request\n");
-				printf("local_conn_id: %lx\n",
-				       ntohl(i->local_conn_id));
-				printf("local_max_packet_size: %lx\n",
-				       ntohl(i->local_max_packet_size));
-				printf("local_target_socket: %lx\n",
-				       ntohl(i->local_target_socket));
-				printf("local_max_send_size: %lx\n",
-				       ntohl(i->local_max_send_size));
-				printf("local_max_recv_size: %lx\n",
-				       ntohl(i->local_max_recv_size));
+				printf("local_conn_id: %x\n",
+				       (u_int32_t)ntohl(i->local_conn_id));
+				printf("local_max_packet_size: %x\n",
+				       (u_int32_t)ntohl(i->local_max_packet_size));
+				printf("local_target_socket: %x\n",
+				       (u_int32_t)ntohl(i->local_target_socket));
+				printf("local_max_send_size: %x\n",
+				       (u_int32_t)ntohl(i->local_max_send_size));
+				printf("local_max_recv_size: %x\n",
+				       (u_int32_t)ntohl(i->local_max_recv_size));
 			}
 			break;
 		case 104:
@@ -617,20 +661,23 @@ void handle_ncp(struct sockaddr_ipx *source,
 				   workstation, and tell me whether anything
 				   of this makes sense at all. */
 
-				switch (data[0]) {
+				switch (data[0])
+				{
 				case 1:
 					printf("Ping for NDS\n");
 					break;
 				case 2:
 					{
-						struct INPUT {
-							__u8 subfunction_code;
-							__u32 fragger_handle;
-							__u32 max_fragment_size;
-							__u32 message_size;
-							__u32 fragment_flag;
-							__u32 verb;
-						} *i = (struct INPUT *) data;
+						struct INPUT
+						{
+							u_int8_t subfunction_code;
+							u_int32_t fragger_handle;
+							u_int32_t max_fragment_size;
+							u_int32_t message_size;
+							u_int32_t fragment_flag;
+							u_int32_t verb;
+						}
+						*i = (struct INPUT *) data;
 						printf("Send NDS Fragment Request/Reply\n");
 						printf("fragger_handle: %lx\n",
 						       (unsigned long) i->fragger_handle);
@@ -642,7 +689,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 						       (unsigned long) i->fragment_flag);
 						printf("verb: %d\n", i->verb);
 
-						switch (i->verb) {
+						switch (i->verb)
+						{
 						case 1:
 							printf("Resolve Name\n");
 							break;
@@ -899,7 +947,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 			printf("fn: %-3d\n", rq->function);
 		}
 	}
-	if (ntohs(rs->type) == NCP_REPLY) {
+	if (ntohs(rs->type) == NCP_REPLY)
+	{
 		printf("NCP respons: conn: %-5d, seq: %-3d, task: %-3d, ",
 		       rs->conn_low + 256 * rs->conn_high,
 		       rs->sequence, rs->task);
@@ -911,20 +960,25 @@ void handle_ncp(struct sockaddr_ipx *source,
 
 		if ((memcmp(&request_source, target,
 			    sizeof(request_source)) == 0)
-		    && (request_header.sequence == rs->sequence)) {
-			switch (request_header.function) {
+		    && (request_header.sequence == rs->sequence))
+		{
+			switch (request_header.function)
+			{
 			case 22:
-				switch (request_data[2]) {
+				switch (request_data[2])
+				{
 				case 18:
 					{
-						struct XDATA {
-							__u8 new_directory_handle;
-							__u8 access_rights_mask;
-						} *x = (struct XDATA *) data;
+						struct XDATA
+						{
+							u_int8_t new_directory_handle;
+							u_int8_t access_rights_mask;
+						}
+						*x = (struct XDATA *) data;
 						printf("new_directory_handle: %x\n",
-						x->new_directory_handle);
+						     x->new_directory_handle);
 						printf("access_rights_mask: %x\n",
-						  x->access_rights_mask);
+						       x->access_rights_mask);
 					}
 					break;
 				}
@@ -935,13 +989,15 @@ void handle_ncp(struct sockaddr_ipx *source,
 				break;
 			case 97:
 				{
-					struct XDATA {
-						__u16 accepted_max_size;
-						__u16 echo_socket;
-						__u8 security_flag;
-					} *x = (struct XDATA *) data;
+					struct XDATA
+					{
+						u_int16_t accepted_max_size;
+						u_int16_t echo_socket;
+						u_int8_t security_flag;
+					}
+					*x = (struct XDATA *) data;
 					printf("accepted_max_size: %x\n",
-					    ntohs(x->accepted_max_size));
+					       ntohs(x->accepted_max_size));
 					printf("echo_socket: %x\n",
 					       ntohs(x->echo_socket));
 					printf("security_flag: %x\n",
@@ -950,44 +1006,55 @@ void handle_ncp(struct sockaddr_ipx *source,
 				break;
 			case 101:
 				{
-					struct XDATA {
-						__u8 completion_code;
-						__u32 remote_target_id;
-						__u32 remote_max_packet_size;
-					} *x = (struct XDATA *) data;
+					struct XDATA
+					{
+						u_int8_t completion_code;
+						u_int32_t remote_target_id;
+						u_int32_t remote_max_packet_size;
+					}
+					*x = (struct XDATA *) data;
 					printf("completion_code: %x\n",
 					       x->completion_code);
-					printf("remote_target_id: %lx\n",
-					     ntohl(x->remote_target_id));
-					printf("remote_max_packet_size: %lx\n",
-					ntohl(x->remote_max_packet_size));
+					printf("remote_target_id: %x\n",
+					       (u_int32_t)ntohl(x->remote_target_id));
+					printf("remote_max_packet_size: %x\n",
+					       (u_int32_t)ntohl(x->remote_max_packet_size));
 				}
 				break;
 			}
 		}
 	}
-	if (data == NULL) {
+	if (data == NULL)
+	{
 		data = buf;
 		data_length = length;
 	}
 	i = 0;
-	while (i < data_length) {
+	while (i < data_length)
+	{
 		int j;
-		for (j = i; j < i + 16; j++) {
-			if (j >= data_length) {
+		for (j = i; j < i + 16; j++)
+		{
+			if (j >= data_length)
+			{
 				printf("  ");
-			} else {
+			} else
+			{
 				printf("%-2.2X", data[j]);
 			}
 		}
 		printf(" ");
-		for (j = i; j < i + 16; j++) {
-			if (j >= data_length) {
+		for (j = i; j < i + 16; j++)
+		{
+			if (j >= data_length)
+			{
 				break;
 			}
-			if (isprint(data[j])) {
+			if (isprint(data[j]))
+			{
 				printf("%c", data[j]);
-			} else {
+			} else
+			{
 				printf(".");
 			}
 		}
@@ -998,7 +1065,8 @@ void handle_ncp(struct sockaddr_ipx *source,
 }
 
 
-void main(int argc, char *argv[])
+int
+main(int argc, char *argv[])
 {
 	unsigned char buf[16384];
 	unsigned char packet[8192];
@@ -1006,13 +1074,16 @@ void main(int argc, char *argv[])
 	int len;
 	int i = 1;
 
-	while (fgets(buf, sizeof(buf), stdin) != NULL) {
-		if (strlen(buf) == sizeof(buf) - 1) {
+	while (fgets(buf, sizeof(buf), stdin) != NULL)
+	{
+		if (strlen(buf) == sizeof(buf) - 1)
+		{
 			fprintf(stderr, "line too long\n");
 			exit(1);
 		}
 		b = strchr(buf, ' ');
-		if (b == NULL) {
+		if (b == NULL)
+		{
 			fprintf(stderr, "illegal line format\n");
 			exit(1);
 		}
@@ -1020,9 +1091,11 @@ void main(int argc, char *argv[])
 		b += 1;
 		len = 0;
 
-		while ((b[0] != '\0') && (b[1] != '\0')) {
+		while ((b[0] != '\0') && (b[1] != '\0'))
+		{
 			unsigned int value;
-			if (sscanf(b, "%2x", &value) != 1) {
+			if (sscanf(b, "%2x", &value) != 1)
+			{
 				fprintf(stderr, "illegal packet\n");
 				exit(1);
 			}
@@ -1033,6 +1106,5 @@ void main(int argc, char *argv[])
 		handle_ipx(packet, len, buf, i);
 		i += 1;
 	}
-
-	exit(0);
+	return 0;
 }
